﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using NUnit.Framework;
using NMock2;

namespace OrderApplication.Tests
{
    [TestFixture]
    public class OrderProcessorNMockTest
    {
        private Mockery _mocks;
        private IOrderFormatter _formatter;
        private IMailSender _sender;
        private OrderProcessor _processor;

        [SetUp]
        public void SetUp()
        {
            _mocks = new Mockery();
            _formatter = _mocks.NewMock<IOrderFormatter>();
            _sender = _mocks.NewMock<IMailSender>();
            _processor = new OrderProcessor(_formatter, _sender);
        }

        [Test]
        public void FormatsMessageAndSendsMailToCustomer()
        {
            var order = new Order {CustomerMail = "ofo@trifork.com"};
            Expect.Once.On(_formatter).Method("Format").With(order).Will(Return.Value("En ordre"));
            Expect.Once.On(_sender).Method("Send").With("ofo@trifork.com", "En ordre");

            _processor.Process(order);

            _mocks.VerifyAllExpectationsHaveBeenMet();
        }
    }
}
